
#################################################################################################
#Computation of the base weights required to the computation of the weights with the GWS method 
#################################################################################################

###############################
#Current cross-sectional weights into the dataset
#2009: equal weights within ea
#2013: household base weights uniform within ea. Each weight divided by the split-off
#      refresh households in refresh ea have equal weights
#2015 the weights change in the ea according to unknown process.
###################
# Computation of the indirect weight according to the technical document:
# For the 2013: use the 2009 household weight for non-refreshed household  
#################
load(file = file.path(base_path, temp_path, "dati.RData"))


#############################
#Building the Xwgt.base weight
#############################
Xwgt09<-dati[!is.na(dati$Xwgt09),c("hhid", "Xwgt09")]
nrow(Xwgt09)
length(unique(Xwgt09$hhid))

Xwgt09<-unique(Xwgt09[c("hhid", "Xwgt09")])
colnames(Xwgt09)<-c("hhid", "Xwgt09.Base")
nrow(Xwgt09)
head(Xwgt09)


datip<-merge (dati, Xwgt09, by="hhid", all.x=T)
#flag_refresh variable= 0 original Household 2009
#flag_refresh variable= 1 original Household 2015
#flag_refresh variable= -1 original Household unknown
datip$flag_refresh=-1 

datip$Xwgt09.Base.p<-ifelse(is.na (datip$Xwgt09.Base), 0 , 1)
datip$flag_refresh<-ifelse(datip$Xwgt09.Base.p==1,0,datip$flag_refresh)

table(datip$Xwgt09.Base.p)#24184 individuals with base weights (note: someone is new individuals)

table(datip$Xwgt09.Base.p, datip$ea_13 )# from ea=324 the ea are of the refresh sample

#verify base weights in the ea are constant 
ck<-datip[datip$Xwgt09.Base.p==1,]
var<-as.data.frame(tapply (ck$Xwgt09.Base, ck$ea_13, var))
ck<-unique(ck[c("ea_13", "Xwgt09")])

ck<-ck[!is.na(ck$ea_13),]
ck<-ck[!is.na(ck$Xwgt09),]
length(unique(ck$ea_13))
colnames(ck)<-c("ea_13", "Xwgt09.Base.ea")

#assign the Xwgt09.Base to each units in the same ea

datip<-merge (datip, ck, by="ea_13", all.x=T)
datip$Xwgt09.Base<-ifelse(is.na (datip$Xwgt09.Base), datip$Xwgt09.Base.ea, datip$Xwgt09.Base )
datip$Xwgt09.Base.p<-ifelse(is.na (datip$Xwgt09.Base), 0 , 1)

datip$flag_refresh<-ifelse(datip$Xwgt09.Base.p==1,0,datip$flag_refresh)

table(datip$Xwgt09.Base.p)#25416 individuals with base weights (note: someone is new individuals)
#9302 individuals in the ea not in refresh with missing base weight

table(datip$Xwgt09.Base.p, datip$ea_13 )#all individual in norefresh ea have the base weight


################
#Refresh individual
#from Ea_13 =324 and over we have the refresh sample
#############?
Xwgt13<-datip[datip$ea_13>=323  & (!is.na(datip$Xwgt13)) ,c("hhid", "Xwgt13")]
nrow(Xwgt13)
head(Xwgt13)
length(unique(Xwgt13$hhid))

Xwgt13<-unique(Xwgt13[c("hhid", "Xwgt13")])
colnames(Xwgt13)<-c("hhid", "Xwgt13.Base")
datip<-merge (datip, Xwgt13, by="hhid", all.x=T)

datip$Xwgt13.Base.p<-ifelse(is.na (datip$Xwgt13.Base), 0 , 1)
datip$flag_refresh<-ifelse(datip$Xwgt13.Base.p==1,1,datip$flag_refresh)

table(datip$Xwgt13.Base.p)#5741 individuals with base weights (note: someone is new individuals)
table (datip$Xwgt13.Base.p, datip$ea_13)#every refresh  hh with ea have the base weight

datip$Xwgt.Base<- ifelse (!is.na (datip$Xwgt09.Base),datip$Xwgt09.Base,datip$Xwgt13.Base) 
datip$Xwgt.Base.p<-ifelse(is.na (datip$Xwgt.Base), 0 , 1)
table (datip$Xwgt.Base.p)



##################################################
#Analysis of individual with missing base weights
##################################################
ck<-datip[datip$Xwgt.Base.p==0,]
nrow(ck)
table(ck$Xwgt05)
table(ck$Xwgt09)
table(ck$Xwgt13)
table(ck$ea_13)
table(ck$refresh)
table(ck$rotate13)
table(ck$attrition)
table(ck$rotate15)
table(ck$rotate15, ck$attrition)
table(ck$rotate13, ck$attrition)

names(ck)

# For individual with missing base weights, and with missing ea
# first case: not-response all in 2009, and response in the succeessive waves 

ckpid<-ck[, c("hhid", "HHID09", "pid")]
ckHHID09<-ckpid[ckpid$HHID09 !="",]#976 indi. con hhID09
ckHHID09<-as.data.frame(unique(ckpid$HHID09))#275 households
library(varhandle)#trasform factor in numeric (note with as.numeric put the level of the factor)
ckHHID09<-unfactor(ckHHID09)
ckHHID09<-ckHHID09[-1,]

names(datip)
ck3<-datip[datip$HHID09 %in% ckHHID09,] 
ck3<-ck3[!is.na(ck3$Xwgt.Base),]
ck3<-unique(ck3[c("HHID09", "Xwgt.Base")])
colnames(ck3)<-c("HHID09", "Xwgt09.Base.agg1")
head(ck3)
datip<-merge(datip, ck3, by="HHID09", all.x=T)
head(datip)
datip$Xwgt.Base<-ifelse(is.na (datip$Xwgt.Base), datip$Xwgt09.Base.agg1, datip$Xwgt.Base)#add 915 weights


datip$flag_refresh<-ifelse(datip$flag_refresh==-1 & 
                          !is.na (datip$Xwgt09.Base.agg1),0,
                          datip$flag_refresh)


datip$Xwgt.Base.p<-ifelse(is.na (datip$Xwgt.Base), 0 , 1)
table (datip$Xwgt.Base.p)
table (datip$Xwgt09.Base.p)
table (datip$Xwgt13.Base.p)
########################################################################?
ck<-datip[datip$Xwgt.Base.p==0,]
nrow(ck)
table(ck$Xwgt05)
table(ck$Xwgt09)
table(ck$Xwgt13)
table(ck$ea_13)
table(ck$refresh)
table(ck$rotate13)
table(ck$attrition)
#                               set=0 
#0_0_0_15 0_0_13_15  0_09_0_0  05_0_0_0 05_09_0_0 
#     508         5        49      2342        12 

ckpid<-ck[, c("hhid", "HHID13", "pid")]#2916 indi. con hhID13
ckHHID13<-ckpid[ckpid$HHID13 !="",]#5 individual in the sample 2013 with HHID13
ckHHID13<-as.data.frame(unique(ckpid$HHID13))
library(varhandle)#trasform factor in numeric (note with as.numeric put the level of the factor)
ckHHID13<-unfactor(ckHHID13)
ckHHID13<-ckHHID13[-1,]

names(datip)
ck3<-datip[datip$HHID13 %in% ckHHID13,] 
ck3<-ck3[!is.na(ck3$Xwgt.Base),]#attention can be from the 2009 sample or refresh
table(ck3$ea_13)#all the individual in norefresh ea!
ck3<-unique(ck3[c("HHID13", "Xwgt.Base")])
colnames(ck3)<-c("HHID13", "Xwgt09or13.Base.agg1")
head(ck3)

datip<-merge(datip, ck3, by="HHID13", all.x=T)
head(datip)

datip$Xwgt.Base<-ifelse(is.na (datip$Xwgt.Base), datip$Xwgt09or13.Base.agg1,datip$Xwgt.Base)#add 5weights

datip$flag_refresh<-ifelse(datip$flag_refresh==-1 & 
                             !is.na (datip$Xwgt09or13.Base.agg1),0,
                           datip$flag_refresh)


datip$Xwgt.Base.p<-ifelse(is.na (datip$Xwgt.Base), 0 , 1)
table (datip$Xwgt.Base.p)
#######################################################################


########################################################################?
#Search for households /individuals responding in 2015 if exist in 2013
#########################################################################
ck<-datip[datip$Xwgt.Base.p==0,]
nrow(ck)
table(ck$Xwgt05)
table(ck$Xwgt09)
table(ck$Xwgt13)
table(ck$ea_13)
table(ck$refresh)
table(ck$rotate13)
table(ck$attrition)

ckpid<-ck[, c("hhid", "HHID15", "pid")]# 
ckHHID15<-ckpid[ckpid$HHID15 !="",]# 508 individuals with HHID15
ckHHID15<-as.data.frame(unique(ckpid$HHID15))#227 hhs
library(varhandle)#trasform factor in numeric (note with as.numeric put the level of the factor)
ckHHID15<-unfactor(ckHHID15)
ckHHID15<-ckHHID15[-1,]

names(datip)
ck3<-datip[datip$HHID13 %in% ckHHID15,]
length(unique(ck3$HHID13)) 
ck3<-ck3[!is.na(ck3$Xwgt.Base),]
nrow(ck3)
#table(ck3$ea_13)#only one ea_13<324 then norefresh. only ea missing base weight in previous step then is norefresh 
ck3<-unique(ck3[c("HHID13", "Xwgt.Base")]) #base weight of households of individuals that do not respond in the 2013
colnames(ck3)<-c("HHID15", "Xwgt09or13.Base.agg2")
head(ck3)
datip<-merge(datip, ck3, by="HHID15", all.x=T)
head(datip)

datip$Xwgt.Base<-ifelse(is.na (datip$Xwgt.Base), datip$Xwgt09or13.Base.agg2 ,datip$Xwgt.Base)

datip$flag_refresh<-ifelse(datip$flag_refresh==-1 & 
                             !is.na (datip$Xwgt09or13.Base.agg2),0,
                           datip$flag_refresh)



datip$Xwgt.Base.p<-ifelse(is.na (datip$Xwgt.Base), 0 , 1)
table (datip$Xwgt.Base.p)

########################################################################?
#Search for households /individuals responding in 2015 if linked with HH 2009/13
#########################################################################
ck<-datip[datip$Xwgt.Base.p==0,]
nrow(ck)
table(ck$Xwgt05)
table(ck$Xwgt09)
table(ck$Xwgt13)
table(ck$ea_13)
table(ck$refresh)
table(ck$rotate13)
table(ck$attrition)

ckpid<-ck[, c("hhid", "HHID15", "pid")]# 
ckHHID15<-ckpid[ckpid$HHID15 !="",]# 397 individuals with HHID15
ckHHID15<-as.data.frame(unique(ckpid$HHID15))
library(varhandle)#trasform factor in numeric (note with as.numeric put the level of the factor)
ckHHID15<-unfactor(ckHHID15)
ckHHID15<-ckHHID15[-1,]

names(datip)
#individuals not responding in the previous wave in hh with already the base weight
ck3<-datip[datip$HHID15 %in% ckHHID15,]
ck3<-ck3[!is.na(ck3$Xwgt.Base),]
length(unique(ck3$HHID13)) 
table(ck3$flag_refresh) 
ck3<-unique(ck3[c("HHID15", "Xwgt.Base","flag_refresh")]) #base weight of households of individuals that do not respond in the 2013
colnames(ck3)<-c("HHID15", "Xwgt.Base09or13.agg3","flag_refresh_agg3")
head(ck3)
datip<-merge(datip, ck3, by="HHID15", all.x=T)
head(datip)
datip$Xwgt.Base<-ifelse(is.na (datip$Xwgt.Base),
                        datip$Xwgt.Base09or13.agg3 ,datip$Xwgt.Base)

datip$flag_refresh<-ifelse(datip$flag_refresh==-1 & 
                 !is.na (datip$flag_refresh_agg3),datip$flag_refresh_agg3,
                  datip$flag_refresh)


datip$Xwgt.Base.p<-ifelse(is.na (datip$Xwgt.Base), 0 , 1)
table (datip$Xwgt.Base.p)

########################################################################?
#Search for households /individuals responding in 2015 if linked with HH 2013/2015
#########################################################################
ck<-datip[datip$Xwgt.Base.p==0,]
nrow(ck)
table(ck$Xwgt05)
table(ck$Xwgt09)
table(ck$Xwgt13)
table(ck$ea_13)
table(ck$refresh)
table(ck$rotate13)
table(ck$attrition)

ckpid<-ck[, c("hhid", "HHID15", "pid")]# 
ckHHID15<-ckpid[ckpid$HHID15 !="",]# 343 individuals with HHID15
ckHHID15<-as.data.frame(unique(ckpid$HHID15))#137 hh
library(varhandle)#trasform factor in numeric (note with as.numeric put the level of the factor)
ckHHID15<-unfactor(ckHHID15)
ckHHID15<-ckHHID15[-1,]

names(datip)
ck3<-datip[datip$HHID15 %in% ckHHID15,]
table (ck3$Xwgt.Base.p)
table (ck3$rotate15)#refresh household non-respondents in 2013 and respondent 2015
ck4<-ck3[!is.na(ck3$Xwgt15),]
var<-as.data.frame(tapply (ck4$Xwgt15, ck4$HHID15, var))#constant weights in the household


length(unique(ck4$HHID15)) 
ck3<-ck3[!is.na(ck3$Xwgt15),]
ck3<-unique(ck3[c("HHID15", "Xwgt15")]) #base weight of households of individuals that do not respond in the 2013
colnames(ck3)<-c("HHID15", "Xwgt15.Base.agg1")
head(ck3)
datip<-merge(datip, ck3, by="HHID15", all.x=T)
head(datip)
datip$Xwgt.Base<-ifelse(is.na (datip$Xwgt.Base), datip$Xwgt15.Base.agg1 ,datip$Xwgt.Base)

datip$flag_refresh<-ifelse(datip$flag_refresh==-1 & 
                             !is.na (datip$Xwgt15.Base.agg1),1,
                           datip$flag_refresh)


datip$Xwgt.Base.p<-ifelse(is.na (datip$Xwgt.Base), 0 , 1)
table (datip$Xwgt.Base.p)

########################################################################?
#Search for households /individuals responding in 2015 if exist in 2013
#########################################################################
ck<-datip[datip$Xwgt.Base.p==0,]
nrow(ck)
table(ck$Xwgt05)
table(ck$Xwgt09)
table(ck$Xwgt13)
table(ck$Xwgt1)
table(ck$ea_13)
table(ck$refresh)
table(ck$rotate15)
table(ck$attrition)
#first pattern: all weights missing in each wave 
#second pattern; to analyse. not usefull for longitudinal analysis
# 0_0_0_15  0_09_0_0  05_0_0_0 05_09_0_0 
# 148        49      2342        12
#00015 households in refresh (see rotate2015) not responding in both 2013-2015
#0900  households norefresh  not responding in 2009 2013 2015
# 5000 never responding
# 5900 there is one hh but there is someting wrong in the HH identifiers (see hhid=1101000102)

table (datip$Xwgt.Base.p)
 
datip$Xwgt.Base<-ifelse(is.na (datip$Xwgt.Base), 0 ,datip$Xwgt.Base)
datip$Xwgt.Base.p<-ifelse(datip$Xwgt.Base==0, 0 , 1)
table (datip$Xwgt.Base.p)

table (datip$Xwgt.Base.p, datip$flag_refresh )

datip$NR2009<-ifelse(datip$flag_refresh==1, 999,
              ifelse(datip$flag_refresh==-1,-1,0))
datip$NR2009<-ifelse(is.na(datip$Xwgt09) & datip$flag_refresh==0,1,
                     datip$NR2009)

datip$NR2013<-ifelse(datip$flag_refresh==0, 999,
                     ifelse(datip$flag_refresh==-1,-1,0))
datip$NR2013<-ifelse(is.na(datip$Xwgt13) & datip$flag_refresh==1,1,
                     datip$NR2013)

datip$NR2015<-ifelse(datip$flag_refresh==-1,-1,0)
datip$NR2015<-ifelse(is.na(datip$Xwgt15) & datip$flag_refresh!=-1,1,
                     datip$NR2015)



table(datip$NR2009)
table(datip$NR2013)
table(datip$NR2015)

table (datip$flag_refresh, datip$refresh)
names(datip)
head(datip)
BaseWeight<-datip[,c("pid", "Xwgt.Base","flag_refresh", "NR2009", "NR2013", "NR2015")]
head(BaseWeight)

save(BaseWeight, file = file.path(base_path, temp_path, "Baseweight.RData"))

rm(ck,ck3,ck4,ckHHID09, ckHHID13, ckHHID15, ckpid,datip,Xwgt09, Xwgt13,var)



