clear all
set more off
clear matrix 

use "$tempfiles\unps_09_13_15_variables4tables.dta", clear

drop _m

destring gwscal, force replace

recode sex_15 (1=2) (2=1)
recode  sex_15 sex_09(2=0)
recode tot_employment09 tot_employment13 tot_employment15 (99=.)
recode urban15   sex_15 lit_pop15 tot_employment15 poor15  dagr_quest15 employees15 employer15 self_employment15 (1=100)
recode  urban09   sex_09  lit_pop09 tot_employment09  poor09  dagr_quest09 employees09 employer09 self_employment09 (1=100)
recode  urban13   sex_13  lit_pop13 tot_employment13  poor13  dagr_quest13 employees13 employer13 self_employment13 (1=100)
recode cellphone15 electricity15 safewater15 runwater15 ownhome15  brickwalls15 nondirtfloor15 solidroof15 internet15 toilet15 (1=100)
recode cellphone13 electricity13 safewater13 runwater13 ownhome13  brickwalls13 nondirtfloor13 solidroof13 internet13 toilet13 (1=100)
recode cellphone09 electricity09 safewater09 runwater09 ownhome09  brickwalls09 nondirtfloor09 solidroof09 internet09 toilet09 (1=100)

gen below18_15=0 if age_15!=.
replace below18_15=1 if (age_15<18)
recode below18_15 (1=100) 

* no weighted statisitics
foreach var in sex_15 below18_15 lit_pop15 tot_employment15 poor15{
mean `var' 
mat mean_`var'=e(b)
mat var_`var'=e(V)
svmat var_`var'
replace var_`var'=sqrt(var_`var')
sum var_`var'

mat se_`var'=r(mean)
mat stat_`var'=mean_`var'
mat list stat_`var'
drop var_`var'
}
mat noweight=stat_sex_15, stat_below18_15, stat_lit_pop15, stat_tot_employment15, stat_poor15
mat noweight=noweight'

*crosssectional weight from the survey
svyset ea_15 [pw=Xwgt15], strata(stratum_15) singleunit(centered)

foreach var in sex_15 below18_15 lit_pop15 tot_employment15 poor15 {
svy: mean `var' 
mat mean_`var'=e(b)
mat var_`var'=e(V)
svmat var_`var'
replace var_`var'=sqrt(var_`var')
sum var_`var'

mat se_`var'=r(mean)
mat stat_`var'=mean_`var'
mat list stat_`var'
drop var_`var'

}
mat sweight=stat_sex_15, stat_below18_15, stat_lit_pop15, stat_tot_employment15, stat_poor15
mat sweight=sweight'

*calibrated weights 
svyset ea_15 [pw= gwscal], strata(stratum_15) singleunit(centered)

foreach var in sex_15 below18_15 lit_pop15 tot_employment15 poor15{
svy: mean `var'
mat mean_`var'=e(b)
mat var_`var'=e(V)
svmat var_`var'
replace var_`var'=sqrt(var_`var')
sum var_`var'

mat se_`var'=r(mean)
mat stat_`var'=mean_`var'
mat list stat_`var'
drop var_`var'

}

mat calweight= stat_sex_15, stat_below18_15, stat_lit_pop15, stat_tot_employment15, stat_poor15  
mat calweight=calweight'
mat stat=noweight,sweight,calweight
mat list stat

putexcel set  "$outputfiles\statistics.xlsx", sheet("S1") modify
putexcel B5 = mat(stat)


* HH LEVEL STATISTICS
preserve 


collapse (mean)  hhsize_15 roomsno15  (max)  urban15  dagr_quest15 cellphone15 electricity15 safewater15  ownhome15  brickwalls15 , by(HHID15 Xwgt15 gwscal ea_15 stratum_15 y2015)


foreach var in  urban15 hhsize_15  dagr_quest15  roomsno15 cellphone15 electricity15 safewater15  ownhome15  brickwalls15   {
mean `var' 
mat mean_`var'=e(b)
mat var_`var'=e(V)
svmat var_`var'
replace var_`var'=sqrt(var_`var')
sum var_`var'

mat se_`var'=r(mean)
mat stat_`var'=mean_`var'
mat list stat_`var'
drop var_`var'
}
mat noweighthh= stat_urban15, stat_hhsize_15,  stat_dagr_quest15,  stat_roomsno15, stat_cellphone15, stat_electricity15, stat_safewater15, stat_ownhome15,  stat_brickwalls15 
mat noweighthh=noweighthh'

*crosssectional weight from the survey
svyset ea_15 [pw=Xwgt15], strata(stratum_15) singleunit(centered)

foreach var in urban15 hhsize_15 dagr_quest15  roomsno15 cellphone15 electricity15 safewater15 ownhome15  brickwalls15   {
svy: mean `var' 
mat mean_`var'=e(b)
mat var_`var'=e(V)
svmat var_`var'
replace var_`var'=sqrt(var_`var')
sum var_`var'

mat se_`var'=r(mean)
mat stat_`var'=mean_`var'
mat list stat_`var'
drop var_`var'

}
mat sweighthh= stat_urban15, stat_hhsize_15, stat_dagr_quest15,  stat_roomsno15, stat_cellphone15,   stat_electricity15, stat_safewater15,  stat_ownhome15,  stat_brickwalls15
mat sweighthh=sweighthh'

*calibrated weights 
svyset ea_15 [pw= gwscal], strata(stratum_15) singleunit(centered)

foreach var in urban15 hhsize_15  dagr_quest15  roomsno15 cellphone15 electricity15 safewater15 ownhome15  brickwalls15  {
svy: mean `var'
mat mean_`var'=e(b)
mat var_`var'=e(V)
svmat var_`var'
replace var_`var'=sqrt(var_`var')
sum var_`var'

mat se_`var'=r(mean)
mat stat_`var'=mean_`var'
mat list stat_`var'
drop var_`var'

}
mat calweighthh=stat_urban15, stat_hhsize_15, stat_dagr_quest15,  stat_roomsno15, stat_cellphone15, stat_electricity15, stat_safewater15, stat_ownhome15,  stat_brickwalls15 
mat calweighthh=calweighthh'
mat stathh=noweighthh,sweighthh,calweighthh
mat list stathh

putexcel set  "$outputfiles\statistics.xlsx", sheet("S1") modify
putexcel B11 = mat(stathh)

restore 

gen tot_employment1= tot_employment09==0&tot_employment15==0 if !missing(tot_employment09)&!missing(tot_employment15)
gen tot_employment2= tot_employment09==0&tot_employment15==100 if !missing(tot_employment09)&!missing(tot_employment15)
gen tot_employment3= tot_employment09==100&tot_employment15==100 if !missing(tot_employment09)&!missing(tot_employment15)
gen tot_employment4= tot_employment09==100&tot_employment15==0 if !missing(tot_employment09)&!missing(tot_employment15)

gen poor1= poor09==0&poor15==0 if !missing(poor09)&!missing(poor15)
gen poor2= poor09==0&poor15==100 if !missing(poor09)&!missing(poor15)
gen poor3= poor09==100&poor15==100 if !missing(poor09)&!missing(poor15)
gen poor4= poor09==100&poor15==0 if !missing(poor09)&!missing(poor15)


* no weighted statisitics
recode tot_employment1 tot_employment2 tot_employment3 tot_employment4 poor1 poor2 poor3 poor4 /*dagr_quest1 dagr_quest2 dagr_quest3 dagr_quest4 */(1=100)

foreach var in tot_employment1 tot_employment2 tot_employment3 tot_employment4 /*ind_1_1 ind_1_2 ind_1_3 ind_1_4*/ poor1 poor2 poor3 poor4 {
mean `var' 
mat mean_`var'=e(b)
mat var_`var'=e(V)
svmat var_`var'
replace var_`var'=sqrt(var_`var')
sum var_`var'

mat se_`var'=r(mean)
mat stat_`var'=mean_`var'
mat list stat_`var'
drop var_`var'
}
mat now1=stat_tot_employment1, stat_tot_employment2, stat_tot_employment3, stat_tot_employment4
mat now1=now1'


mat now2=stat_poor1, stat_poor2, stat_poor3, stat_poor4
mat now2=now2'

*crosssectional weight from the survey
svyset ea_15 [pw=Xwgt15], strata(stratum_15) singleunit(centered)

foreach var in tot_employment1 tot_employment2 tot_employment3 tot_employment4 /*ind_1_1 ind_1_2 ind_1_3 ind_1_4*/ poor1 poor2 poor3 poor4{
svy: mean `var' 
mat mean_`var'=e(b)
mat var_`var'=e(V)
svmat var_`var'
replace var_`var'=sqrt(var_`var')
sum var_`var'

mat se_`var'=r(mean)
mat stat_`var'=mean_`var'
mat list stat_`var'
drop var_`var'
}
mat sw1=stat_tot_employment1, stat_tot_employment2, stat_tot_employment3, stat_tot_employment4
mat sw1=sw1'

mat sw2=stat_poor1, stat_poor2, stat_poor3, stat_poor4
mat sw2=sw2'

*calibrated weights 
svyset ea_15 [pw= gwscal], strata(stratum_15) singleunit(centered)

foreach var in tot_employment1 tot_employment2 tot_employment3 tot_employment4 /*ind_1_1 ind_1_2 ind_1_3 ind_1_4*/ poor1 poor2 poor3 poor4{
svy: mean `var' 
mat mean_`var'=e(b)
mat var_`var'=e(V)
svmat var_`var'
replace var_`var'=sqrt(var_`var')
sum var_`var'

mat se_`var'=r(mean)
mat stat_`var'=mean_`var'
mat list stat_`var'
drop var_`var'
}
mat calw1=stat_tot_employment1, stat_tot_employment2, stat_tot_employment3, stat_tot_employment4
mat calw1=calw1'

mat calw2=stat_poor1, stat_poor2, stat_poor3, stat_poor4
mat calw2=calw2'


gen tot_employment1a= tot_employment13==0&tot_employment15==0 if !missing(tot_employment13)&!missing(tot_employment15)
gen tot_employment2a= tot_employment13==0&tot_employment15==100 if !missing(tot_employment13)&!missing(tot_employment15)
gen tot_employment3a= tot_employment13==100&tot_employment15==100 if !missing(tot_employment13)&!missing(tot_employment15)
gen tot_employment4a= tot_employment13==100&tot_employment15==0 if !missing(tot_employment13)&!missing(tot_employment15)

gen poor1a= poor13==0&poor15==0 if !missing(poor13)&!missing(poor15)
gen poor2a= poor13==0&poor15==100 if !missing(poor13)&!missing(poor15)
gen poor3a= poor13==100&poor15==100 if !missing(poor13)&!missing(poor15)
gen poor4a= poor13==100&poor15==0 if !missing(poor13)&!missing(poor15)

* no weighted statisitics
recode tot_employment1a tot_employment2a tot_employment3a tot_employment4a poor1a poor2a poor3a poor4a /*dagr_quest1a dagr_quest2a dagr_quest3a dagr_quest4a*/ (1=100)

foreach var in tot_employment1a tot_employment2a tot_employment3a tot_employment4a /*ind_1_1a ind_1_2a ind_1_3a ind_1_4a*/ poor1a poor2a poor3a poor4a {
mean `var' 
mat mean_`var'=e(b)
mat var_`var'=e(V)
svmat var_`var'
replace var_`var'=sqrt(var_`var')
sum var_`var'

mat se_`var'=r(mean)
mat stat_`var'=mean_`var'
mat list stat_`var'
drop var_`var'
}
mat now1a=stat_tot_employment1a, stat_tot_employment2a, stat_tot_employment3a, stat_tot_employment4a
mat now1a=now1a'

mat now2a=stat_poor1a, stat_poor2a, stat_poor3a, stat_poor4a
mat now2a=now2a'

svyset ea_15 [pw=Xwgt15], strata(stratum_15) singleunit(centered)

foreach var in tot_employment1a tot_employment2a tot_employment3a tot_employment4a /*ind_1_1a ind_1_2a ind_1_3a ind_1_4a*/ poor1a poor2a poor3a poor4a{
svy: mean `var' 
mat mean_`var'=e(b)
mat var_`var'=e(V)
svmat var_`var'
replace var_`var'=sqrt(var_`var')
sum var_`var'

mat se_`var'=r(mean)
mat stat_`var'=mean_`var'
mat list stat_`var'
drop var_`var'
}
mat sw1a=stat_tot_employment1a, stat_tot_employment2a, stat_tot_employment3a, stat_tot_employment4a
mat sw1a=sw1a'

mat sw2a=stat_poor1a, stat_poor2a, stat_poor3a, stat_poor4a
mat sw2a=sw2a'
svyset ea_15 [pw= gwscal], strata(stratum_15) singleunit(centered)

foreach var in tot_employment1a tot_employment2a tot_employment3a tot_employment4a /*ind_1_1a ind_1_2a ind_1_3a ind_1_4a*/ poor1a poor2a poor3a poor4a{
svy: mean `var' 
mat mean_`var'=e(b)
mat var_`var'=e(V)
svmat var_`var'
replace var_`var'=sqrt(var_`var')
sum var_`var'

mat se_`var'=r(mean)
mat stat_`var'=mean_`var'
mat list stat_`var'
drop var_`var'
}
mat calw1a=stat_tot_employment1a, stat_tot_employment2a, stat_tot_employment3a, stat_tot_employment4a
mat calw1a=calw1a'
*mat calw4a=stat_ind_1_1a, stat_ind_1_2a, stat_ind_1_3a, stat_ind_1_4a
*mat calw4a=calw4a'
mat calw2a=stat_poor1a, stat_poor2a, stat_poor3a, stat_poor4a
mat calw2a=calw2a'


mat s1=now1, sw1,calw1  
mat s2=now2, sw2,calw2  
 
mat s1a=now1a, sw1a,calw1a  
mat s2a=now2a, sw2a,calw2a  

putexcel set  "$outputfiles\statistics.xlsx", sheet("S2") modify
putexcel B5 = mat(s1)
putexcel B14 = mat(s2)

putexcel E5 = mat(s1a)
putexcel E14 = mat(s2a)

foreach var in tot_employment1 tot_employment2 tot_employment3 tot_employment4 tot_employment1a tot_employment2a tot_employment3a tot_employment4a /*ind_1_1 ind_1_2 ind_1_3 ind_1_4 ind_1_1a ind_1_2a ind_1_3a ind_1_4a*/ poor1 poor2 poor3 poor4 poor1a poor2a poor3a poor4a{
mean `var', over(urban15)
mat nwmean_`var'==e(b)' 
mat v_nw`var'=e(V)
mat Var_nw`var'=vecdiag( v_nw`var')

svmat Var_nw`var'
rename Var_nw`var'* se_nw`var'*
foreach j of numlist 1/2{
replace se_nw`var'`j'=sqrt(se_nw`var'`j')
sum se_nw`var'`j'
mat se_nw`var'`j'=r(mean)
}
mat se_nw`var'=se_nw`var'1\ se_nw`var'2

foreach weight in Xwgt15 gwscal{

svyset ea_15 [pw=`weight'], strata(stratum_15) singleunit(centered)
svy: mean `var', over(urban15)

mat mean_`var'_`weight'==e(b)' 
mat v_`var'_`weight'=e(V)
mat Var_`var'_`weight'=vecdiag( v_`var'_`weight')

svmat Var_`var'_`weight'
rename Var_`var'_`weight'* se_`var'_`weight'*
foreach j of numlist 1/2{
replace se_`var'_`weight'`j'=sqrt(se_`var'_`weight'`j')
sum se_`var'_`weight'`j'
mat se_`var'_`weight'`j'=r(mean)

}
mat se_`var'_`weight'=se_`var'_`weight'1\ se_`var'_`weight'2
}
mat `var'=nwmean_`var',mean_`var'_Xwgt15, mean_`var'_gwscal


}

mat tot_employment=tot_employment1\tot_employment2\tot_employment3\tot_employment4
mat tot_employment_a=tot_employment1a\tot_employment2a\tot_employment3a\tot_employment4a



mat poor = poor1\ poor2\ poor3 \ poor4 
mat poora = poor1a\ poor2a \ poor3a \ poor4a 

putexcel set  "$outputfiles\statistics.xlsx", sheet("rur_urb") modify
putexcel C5 = mat(tot_employment)
putexcel F5 = mat(tot_employment_a)

putexcel C19 = mat(poor) 
putexcel F19 = mat(poora) 

*******************************
* UNHS comparison statisitics *
*******************************

drop se_*


keep if gwscal!=.
foreach over in urban15 /*sex_15*/{
foreach var in /*lit_pop15*/ tot_employment15 poor15{
mean `var', over(`over')
mat nwmean_`var'==e(b)' 
mat v_nw`var'=e(V)
mat Var_nw`var'=vecdiag( v_nw`var')

svmat Var_nw`var'
rename Var_nw`var'* se_nw`var'*
foreach j of numlist 1/2{
replace se_nw`var'`j'=sqrt(se_nw`var'`j')
sum se_nw`var'`j'
mat se_nw`var'`j'=r(mean)
}
mat se_nw`var'=se_nw`var'1\ se_nw`var'2

foreach weight in Xwgt15 gwscal{



svyset ea_15 [pw=`weight'], strata(stratum_15) singleunit(centered)
svy: mean `var', over(`over')

mat mean_`var'_`weight'==e(b)' 
mat v_`var'_`weight'=e(V)
mat Var_`var'_`weight'=vecdiag( v_`var'_`weight')

svmat Var_`var'_`weight'
rename Var_`var'_`weight'* se_`var'_`weight'*
foreach j of numlist 1/2{
replace se_`var'_`weight'`j'=sqrt(se_`var'_`weight'`j')
sum se_`var'_`weight'`j'
mat se_`var'_`weight'`j'=r(mean)

}
mat se_`var'_`weight'=se_`var'_`weight'1\ se_`var'_`weight'2

}
mat `over'_`var'=nwmean_`var',mean_`var'_Xwgt15,mean_`var'_gwscal
drop  se_*

}
}

mat list urban15_tot_employment15
mat list urban15_poor15



putexcel set  "$outputfiles\statistics.xlsx", sheet("Employed") modify
putexcel B4 = mat(urban15_tot_employment15)

putexcel set  "$outputfiles\statistics.xlsx", sheet("Pov") modify
putexcel B4=mat(urban15_poor15)



















ex

